about summary refs log tree commit diff
path: root/sysdeps/mach/hurd/profil.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/mach/hurd/profil.c')
-rw-r--r--sysdeps/mach/hurd/profil.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sysdeps/mach/hurd/profil.c b/sysdeps/mach/hurd/profil.c
index b3f201b016..952398b4fa 100644
--- a/sysdeps/mach/hurd/profil.c
+++ b/sysdeps/mach/hurd/profil.c
@@ -141,7 +141,7 @@ weak_alias (__profil, profil)
 static volatile error_t special_profil_failure;
 
 /* Fetch PC samples.  This function must be very careful not to depend
-   on Hurd threadvar variables.  We arrange that by using a special
+   on Hurd TLS variables.  We arrange that by using a special
    stub arranged for at the end of this file. */
 static void
 fetch_samples (void)
@@ -176,7 +176,7 @@ fetch_samples (void)
 }
 
 
 /* This function must be very careful not to depend on Hurd threadvar
    variables.  We arrange that by using special stubs arranged for at the
    end of this file. */
 static void
@@ -267,7 +267,7 @@ text_set_element (_hurd_fork_child_hook, fork_profil_child);
    are fatal in profile_waiter anyhow. */
 #define __mig_put_reply_port(foo)
 
 /* Use our static variable instead of the usual threadvar mechanism for
    this. */
 #define __mig_get_reply_port() profil_reply_port
@@ -176,7 +176,7 @@ fetch_samples (void)
 
 
-/* This function must be very careful not to depend on Hurd threadvar
+/* This function must be very careful not to depend on Hurd TLS
    variables.  We arrange that by using special stubs arranged for at the
    end of this file. */
@@ -267,7 +267,7 @@ text_set_element (_hurd_fork_child_hook, fork_profil_child);
 #define __mig_put_reply_port(foo)
 
-/* Use our static variable instead of the usual threadvar mechanism for
+/* Use our static variable instead of the usual TLS mechanism for
    this. */
 #define __mig_get_reply_port() profil_reply_port